@@ -61,8 +61,6 @@ __workers__ = []
 __telegrambot_name__ = 'ht-bot'
 __telegrambot_token__ = ''
 
-__modulesLoadesThreadNames__ = []
-
 def __checkLibraryUpdate__():
     try:
         # Check Version Update
@@ -111,7 +109,7 @@ def getCategories():
             data.append(mods.split('.')[1])
     return data
 
-def getModule(moduleName):
+def getModule(moduleName, waiting=False):
     """Return's and load's a module into a variable passing a module name as parameter
 
     Parameters
@@ -123,27 +121,19 @@ def getModule(moduleName):
         eval(module)
     """
     #Logger.printMessage('Initiation of {moduleName}'.format(moduleName=moduleName), debug_module=True)
-
-    print(__modulesLoadesThreadNames__)
-    print(__modules_loaded__)
-    print(getWorkers())
     
     for m in __modules_loaded__:
         if moduleName in m:
             if not 'ht_' in moduleName:
                 moduleName = 'ht_{m}'.format(m=moduleName)
-            __modulesLoadesThreadNames__.remove(moduleName)
             sentence = 'modules.{category}.{mod}.{moduleName}.StartModule()'.format(category=m.split('.')[1], mod='_'.join(moduleName.split('_')[1:]), moduleName=moduleName)
             return eval(sentence)
 
-    # Prevents any module not been fully loaded yet
-    if moduleName in __modulesLoadesThreadNames__:
-        for worker in getWorkers():
-            if moduleName in worker:
-                __sleep(0.1)
-                return getModule(moduleName)
-
-    Logger.printMessage('Looks like {mod} is not loaded on HackingTools. Look the first import in log. You could have some error in your code :)'.format(mod=moduleName), is_error=True)
+    if not waiting:
+        __sleep(0.5)
+        getModule(moduleName, True)
+    else:
+        Logger.printMessage('Looks like {mod} is not loaded on HackingTools. Look the first import in log. You could have some error in your code :)'.format(mod=moduleName), is_error=True)
 
 def getModules():
     data = []
@@ -548,7 +538,7 @@ def __importModule__(modules, category, moduleName):
                 __modules_loaded__[module_import_string_no_from][mod_func]['original_params'] = original_params if original_params else None
         else:
             __modules_loaded__[module_import_string_no_from] = 'Sin funciones...'
-        __modulesLoadesThreadNames__.remove(moduleName)
+
     except Exception as e:
         Logger.printMessage(str(e), is_error=True)
         new_module_name = str(e).split("'")[1]
@@ -593,7 +583,6 @@ def __importModules__():
                 try:
                     module_name = modules[modu][submod][files][0].split(".")[0]
                     if not __amidjango__:
-                        __modulesLoadesThreadNames__.append(module_name)
                         worker("import-module-{m}".format(m=module_name), 'ht.__importModule__', args=(modu, submod, module_name), loop=False, log=False) # Threaded
                     else:
                         __importModule__(modules=modu, category=submod, moduleName=module_name)
